﻿angular.module("umbraco")
    .controller("MediaProtect.Dialogs.ProtectController",
    function ($scope, mediaprotectBackofficeResources, dialogService, notificationsService, navigationService) {

        var nodeId = $scope.$parent.currentAction.metaData.nodeId;
        $scope.selectedProtectionMode = 'RoleProtection';
        $scope.selectedAvailableoptions = [];
        $scope.notselectedAvailableoptions = [];
        $scope.errorMessages = [];
        $scope.showRemoveDialog = false;

        $scope.bindData = function () {
            mediaprotectBackofficeResources.initializeDialogResource(nodeId).then(function (res) {
                $scope.model = res.data;
                $scope.loaded = true;
            });
        };

        $scope.select = function () {
            $scope.model.dialogState = $scope.selectedProtectionMode;
        }

        $scope.removeProtection = function() {
            $scope.showRemoveDialog = true;
        }

        $scope.cancelRemoveProtection = function () {
            $scope.showRemoveDialog = false;
        }

        $scope.performRemoveProtection = function () {
            mediaprotectBackofficeResources.removeProtection($scope.model).then(function (res) {
                notificationsService.success(res.data.header, res.data.description);
                navigationService.syncTree({ tree: "media", path: $scope.model.nodePath.split(","), forceReload: true });
                navigationService.hideDialog();
            });
        }


        $scope.selectRoles = function () {
            mediaprotectBackofficeResources.addRolesResource($scope.notselectedAvailableoptions, $scope.model.roleInfo).then(function (res) {
                $scope.model.roleInfo = res.data;
                $scope.notselectedAvailableoptions = [];
            });
        }

        $scope.deselectRoles = function () {
            mediaprotectBackofficeResources.removeRolesResource($scope.selectedAvailableoptions, $scope.model.roleInfo).then(function (res) {
                $scope.model.roleInfo = res.data;
                $scope.selectedAvailableoptions = [];
            });
        }

        $scope.selectLoginNode = function () {
            dialogService.contentPicker({
                multiPicker: false,
                callback: function (data) {
                    $scope.model.loginNodeId = data.id;
                    $scope.model.loginNodeName = data.name;
                }
            });
        };

        $scope.selectNoRightsNode = function () {
            dialogService.contentPicker({
                multiPicker: false,
                callback: function (data) {
                    $scope.model.noRightsNodeId = data.id;
                    $scope.model.noRightsNodeName = data.name;
                }
            });
        };

        $scope.deleteLoginNode = function () {
            $scope.model.loginNodeId = 0;
            $scope.model.loginNodeName = '';
        };

        $scope.deleteNoRightsNode = function () {
            $scope.model.noRightsNodeId = 0;
            $scope.model.noRightsNodeName = '';
        };

        $scope.validateForm = function (callback) {
            mediaprotectBackofficeResources.validate($scope.model).then(function (res) {
                $scope.errorMessages = res.data.errorMessages;
                if (res.data.isValid) {
                    callback();
                }
            });
        }

        $scope.save = function () {
            $scope.validateForm($scope.doSave);
        }

        $scope.doSave = function () {
                mediaprotectBackofficeResources.save($scope.model).then(function (res) {
                    notificationsService.success(res.data.header, res.data.description);
                    navigationService.syncTree({ tree: "media", path: $scope.model.nodePath.split(","), forceReload: true });
                    navigationService.hideDialog();
                    mediaprotectBackofficeResources.reIndex($scope.model.nodeId);
                });
        }

        //Initialize
        $scope.bindData();
    });